from redis import RedisDict
from memory import MemoryDict
from models import ModelDict
from zookeeper import ZookeeperDict